@@ -156,6 +156,8 @@ class PlanetView(gobject.GObject):
 			self._handlers.append((self._app.disconnect, h_id))
 			h_id = self._app.connect('entries-unviewed', self.__entries_updated_cb)
 			self._handlers.append((self._app.disconnect, h_id))
+			h_id = app.connect('new-database', self.__new_database_cb)
+			self._handlers.append((app.disconnect, h_id))
 		screen = gtk.gdk.screen_get_default()
 		h_id = screen.connect('size-changed', self.__size_changed_cb)
 		self._handlers.append((screen.disconnect, h_id))
@@ -206,12 +208,14 @@ class PlanetView(gobject.GObject):
 			logging.info("initializing ajax server")
 			import threading
 			from ajax import EntryInfoServer, MyTCPServer
+			
+			store_location = os.path.join(self._db.get_setting(ptvDB.STRING, '/apps/penguintv/media_storage_location', ""), "images")
 
 			while True:
 				try:
 					if PlanetView.PORT == 8050:
 						break
-					self._update_server = MyTCPServer.MyTCPServer(('', PlanetView.PORT), EntryInfoServer.EntryInfoServer)
+					self._update_server = MyTCPServer.MyTCPServer(('', PlanetView.PORT), EntryInfoServer.EntryInfoServer, store_location)
 					break
 				except:
 					PlanetView.PORT += 1
@@ -220,12 +224,12 @@ class PlanetView(gobject.GObject):
 			t = threading.Thread(None, self._update_server.serve_forever, name="PTV AJAX Server Thread")
 			t.setDaemon(True)
 			t.start()
-			img_url = "http://localhost:"+str(PlanetView.PORT)+"/"+self._update_server.get_key()
-			self._entry_formatter = EntryFormatter.EntryFormatter(self._mm, False, True, ajax_url=img_url)
-			self._search_formatter = EntryFormatter.EntryFormatter(self._mm, True, True, ajax_url=img_url)
+			self._ajax_url = "http://localhost:"+str(PlanetView.PORT)+"/"+self._update_server.get_key()
+			self._entry_formatter = EntryFormatter.EntryFormatter(self._mm, False, True, ajax_url=self._ajax_url)
+			self._search_formatter = EntryFormatter.EntryFormatter(self._mm, True, True, ajax_url=self._ajax_url)
 		else:
 			logging.info("not using ajax")
-			img_url = None
+			self._ajax_url = None
 			self._entry_formatter = EntryFormatter.EntryFormatter(self._mm, False, True, basic_progress=True)
 			self._search_formatter = EntryFormatter.EntryFormatter(self._mm, True, True, basic_progress=True)
 		
@@ -282,6 +286,9 @@ class PlanetView(gobject.GObject):
 		"""Redraw after xrandr calls"""
 		self._render_entries()
 		
+	def __new_database_cb(self, app, db):
+		self._db = db
+		
 	def grab_focus(self):
 		if utils.RUNNING_SUGAR:
 			self._moz.grab_focus()
@@ -543,7 +550,7 @@ class PlanetView(gobject.GObject):
 		html = []
 		html.append(self._build_header(media_exists))
 		
-		html.append(self._custom_message)
+		html.append(self._custom_message+"<br>")
 		
 		if utils.RUNNING_HILDON:
 			html.append('<a href="pane:back"><img border="0" src="file://%s"/>%s</a>' % (
@@ -703,7 +710,7 @@ class PlanetView(gobject.GObject):
 		#load the rest from db
 		if len(entry_list) > 0:
 			e_id_list = [r[0] for r in entry_list]
-			db_entries = self._db.get_entry_block(e_id_list)
+			db_entries = self._db.get_entry_block(e_id_list, self._ajax_url)
 			media = self._db.get_entry_media_block(e_id_list)
 		
 			for item in db_entries:
@@ -737,7 +744,7 @@ class PlanetView(gobject.GObject):
 		if self._entry_store.has_key(entry_id) and not force:
 			return self._entry_store[entry_id]
 		
-		item = self._db.get_entry(entry_id)
+		item = self._db.get_entry(entry_id, self._ajax_url)
 		media = self._db.get_entry_media(entry_id)
 		if media:
 			item['media']=media
